@@ -1,8 +1,10 @@
 import unittest
 from time import sleep
+from selenium.webdriver import Chrome
 from seldom.webdriver import WebDriver
 from seldom.running.config import Seldom
 from seldom.logging import log
+from seldom.logging.exceptions import NotFindElementError
 
 
 class TestCase(unittest.TestCase, WebDriver):
@@ -21,6 +23,8 @@ class TestCase(unittest.TestCase, WebDriver):
 
     @classmethod
     def setUpClass(cls):
+        if Seldom.driver is None:
+            Seldom.driver = Chrome()
         cls().start_class()
 
     @classmethod
@@ -45,6 +49,15 @@ class TestCase(unittest.TestCase, WebDriver):
     def tearDown(self):
         self.end()
 
+    @property
+    def driver(self):
+        """
+        browser driver
+        """
+        if Seldom.driver is None:
+            Seldom.driver = Chrome()
+        return Seldom.driver
+
     def assertTitle(self, title=None, msg=None):
         """
         Asserts whether the current title is in line with expectations.
@@ -161,6 +174,44 @@ class TestCase(unittest.TestCase, WebDriver):
         alert_text = self.get_alert_text()
         self.assertEqual(alert_text, text, msg=msg)
 
+    def assertElement(self, msg=None, **kwargs):
+        """
+        Asserts whether the element exists.
+
+        Usage:
+        self.assertElement("text")
+        """
+        if msg is None:
+            msg = "No elements found"
+        for _ in range(Seldom.timeout):
+            try:
+                log.info("👀 assertElement.")
+                self.get_elements(**kwargs)
+                break
+            except NotFindElementError:
+                sleep(1)
+        else:
+            print("time out")
+            self.assertTrue(False, msg=msg)
+
+    def assertNotElement(self, msg=None, **kwargs):
+        """
+        Asserts if the element does not exist.
+
+        Usage:
+        self.assertNotElement("text")
+        """
+        if msg is None:
+            msg = "Find the element"
+
+            try:
+                log.info("👀 assertNotElement.")
+                self.get_elements(**kwargs)
+            except NotFindElementError:
+                pass
+            else:
+                self.assertFalse(True, msg=msg)
+
     def xSkip(self, reason):
         """
         Skip this test.
