@@ -41,13 +41,17 @@ def main():
         help="show version")
 
     parser.add_argument(
-        '--project',
+        '-project',
         help="Create an Seldom automation test project.")
 
     parser.add_argument(
         '-r',
         help="run test case")
 
+    parser.add_argument(
+        '-m',
+        help="run tests modules, classes or even individual test methods from the command line ")
+
     parser.add_argument(
         '-install',
         help="Install the browser driver, For example, 'chrome', 'firefox'. ")
@@ -55,7 +59,7 @@ def main():
     args = parser.parse_args()
 
     if args.version:
-        print("version {}".format(__version__))
+        print("seldom {}".format(__version__))
         return 0
 
     project_name = args.project
@@ -65,11 +69,13 @@ def main():
 
     run_file = args.r
     if run_file:
-        log.info("Run the python version:")
+        print("Runtime environment:")
+        print("---------------------")
         if PY3:
-            ret = os.system("python -V")
-            if ret != 0:
-                os.system("python3 -V")
+            ret = os.system("python3 -V")
+            os.system("seldom -v")
+            print("---------------------")
+            if ret == 0:
                 command = "python3 " + run_file
             else:
                 command = "python " + run_file
@@ -78,6 +84,25 @@ def main():
         os.system(command)
         return 0
 
+    run_case = args.m
+    if run_case:
+        print("Runtime environment:")
+        print("---------------------")
+        print("Note: This mode is suitable for debugging single test classes and methods.")
+        if PY3:
+            ret = os.system("python3 -V")
+            os.system("seldom -v")
+            print("Browser: Chrome(default)")
+            print("---------------------")
+            if ret == 0:
+                command = "python3 -m unittest " + run_case
+            else:
+                command = "python -m unittest " + run_case
+        else:
+            raise NameError("Does not support python2")
+        os.system(command)
+        return 0
+
     driver_name = args.install
     if driver_name:
         install_driver(driver_name)
@@ -106,21 +131,45 @@ def create_scaffold(project_name):
         msg = "created file: {}".format(path)
         log.info(msg)
 
-    test_sample = '''import seldom
+    test_data = '''{
+ "baidu":  [
+    ["case1", "seldom"],
+    ["case2", "poium"],
+    ["case3", "HTMLTestRunner"]
+ ]
+}
+
+'''
+    test_sample = '''import os
+import seldom
+from seldom import file_data
+CASE_DIR = os.path.dirname(os.path.abspath(__file__))
+# data file path
+YAML_FILE = os.path.join(CASE_DIR, "data.json")
 
 
-class YouTest(seldom.TestCase):
+class SampleTest(seldom.TestCase):
 
     def test_case(self):
         """a simple test case """
-        self.open("https://www.baidu.com")
-        self.type(id_="kw", text="seldom")
+        self.get("http://www.itest.info")
+        self.assertInUrl("itest.info")
+
+
+class BaiduTest(seldom.TestCase):
+
+    @file_data(file=YAML_FILE, key="baidu")
+    def test_data_driver(self, _, keyword):
+        """ data driver case """
+        self.get("https://www.baidu.com")
+        self.type(id_="kw", text=keyword)
         self.click(css="#su")
-        self.assertInTitle("seldom")
+        self.assertInTitle(keyword)
 
 
 if __name__ == '__main__':
     seldom.main(debug=True)
+
 '''
     run_test = """import seldom
 
@@ -134,6 +183,7 @@ if __name__ == '__main__':
     create_folder(project_name)
     create_folder(os.path.join(project_name, "test_dir"))
     create_folder(os.path.join(project_name, "reports"))
+    create_file(os.path.join(project_name, "test_dir", "data.json"), test_data)
     create_file(os.path.join(project_name, "test_dir", "test_sample.py"), test_sample)
     create_file(os.path.join(project_name, "run.py"), run_test)
 
@@ -171,7 +221,7 @@ def chrome(_os=None, os_bit=None):
     :param os_bit: system bit
     :return:
     """
-    latest_version = '85.0.4183.87'
+    latest_version = '89.0.4389.23'
     base_download = "https://cdn.npm.taobao.org/dist/chromedriver/%s/chromedriver_%s%s.zip"
     download = base_download % (latest_version, _os, os_bit)
     return 'chromedriver', download, latest_version
