@@ -78,19 +78,19 @@ def main(path=None,
     else:
         BrowserConfig.name = browser
 
-    # set timeout
-    if isinstance(timeout, int):
-        Seldom.timeout = timeout
-    else:
+    if isinstance(timeout, int) is False:
         raise TypeError("Timeout {} is not integer.".format(timeout))
 
-    # set debug
-    Seldom.debug = debug
+    if isinstance(debug, bool) is False:
+        raise TypeError("Debug {} is not Boolean type.".format(timeout))
 
     """
-    Global launch browser
+    Global launch browser, timeout and debug.
     """
-    Seldom.driver = Browser(BrowserConfig.name).driver
+    browser = Browser(BrowserConfig.name).driver
+    Seldom.driver = browser
+    Seldom.timeout = timeout
+    Seldom.debug = timeout
 
     if debug is False:
         for filename in os.listdir(os.getcwd()):
